==> ejc-bfyjerp-impl-3.0.0-20241120.022203-43-sources.jar: com/ejianc/business/oa/mapper/InstoreDetailMapper.java <==
package com.ejianc.business.oa.mapper;

import com.ejianc.business.oa.vo.InstoreDetailVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.oa.bean.InstoreDetailEntity;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 人力行政-资产入库单子表
 * 
 * @author generator
 * 
 */
@Mapper
public interface InstoreDetailMapper extends BaseCrudMapper<InstoreDetailEntity> {

    Long queryStoreCanUseNumPageDataCount(@Param("searchText") String searchText,
                                          @Param("outDate") String outDate,
                                          @Param("storeId") Long storeId,
                                          @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit
    );

    List<InstoreDetailVO> queryStoreCanUseNumPageData(@Param("searchText") String searchText,
                                                        @Param("outDate") String outDate,
                                                        @Param("storeId") Long storeId,
                                                        @Param("startLine") Integer startLine,
                                                        @Param("pageSize") Integer pageSize,
                                                        @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit);

}

==> ejc-bfyjerp-impl-3.0.0-20241120.082659-49-sources.jar: com/ejianc/business/oa/mapper/InstoreDetailMapper.java <==
package com.ejianc.business.oa.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.oa.vo.InstoreDetailVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.oa.bean.InstoreDetailEntity;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 人力行政-资产入库单子表
 * 
 * @author generator
 * 
 */
@Mapper
public interface InstoreDetailMapper extends BaseCrudMapper<InstoreDetailEntity> {

    Long queryStoreCanUseNumPageDataCount(@Param("searchText") String searchText,
                                          @Param("outDate") String outDate,
                                          @Param("storeId") Long storeId,
                                          @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit
    );

    List<InstoreDetailVO> queryStoreCanUseNumPageData(@Param("searchText") String searchText,
                                                        @Param("outDate") String outDate,
                                                        @Param("storeId") Long storeId,
                                                        @Param("startLine") Integer startLine,
                                                        @Param("pageSize") Integer pageSize,
                                                        @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit);

    List<InstoreDetailVO> queryStoreData(Page pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper);
}
